
# arq-worker
 A high level abstraction designed for running [arq](https://github.com/samuelcolvin/arq) in api-driven apps/frameworks

---
## Quickstart

```bash
# From pypi
pip install --upgrade arq-worker

# From source
pip install --upgrade git+https://github.com/trisongz/arq-worker
```

## Usage

```python
import arqworker

## Do something here

```

---

## Libraries & Dependencies

- `Python 3.7`

- `lazycls`

- `pylogz`

- `arq`

- `redis`


---

This Python Library has been autogenerated with [pylibup](https://github.com/trisongz/pylibup).
